#
# spec file for package python-pylzma
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define oname   pylzma
Name:           python-pylzma
Version:        0.5.0
Release:        4.3
Summary:        Python bindings for the LZMA compression library
License:        LGPL-2.1-only
URL:            https://github.com/fancycode/pylzma
Source0:        https://github.com/fancycode/pylzma/archive/v%{version}.tar.gz
# PATCH-FIX-UPSTREAM python-pylzma-test-python3.patch gh#fancycode/pylzma#76 mcepl@suse.com
# use python3 syntax in test_usage.py
Patch0:         python-pylzma-test-python3.patch
# PATCH-FIX-UPSTREAM python-pylzma-gcc14.patch gh#fancycode/pylzma#81 glaubitz@suse.com
Patch1:         python-pylzma-gcc14.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%python_subpackages

%description
PyLZMA provides a platform independent way to read and write data
that has been compressed or can be decompressed by the LZMA library.

%prep
%autosetup -p1 -n %{oname}-%{version}
# No .dev0 builds please
rm -rf pylzma.egg-info setup.cfg

# Remove Shebang
sed -i '1d' py7zlib.py

%build
echo %{version} > RELEASE-VERSION
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pyunittest_arch discover -v

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitearch}/py7zlib.py
%pycache_only %{python_sitearch}/__pycache__/py7zlib.*.py*
%{python_sitearch}/%{oname}.cpython-*.so
%{python_sitearch}/%{oname}-%{version}.dist-info

%changelog
* Thu Jun 13 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Cherry-pick upstream patch to fix build with GCC 14
  * python-pylzma-gcc14.patch
* Fri Mar  8 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to autosetup and pyproject macro.
- Less globs in %%files.
* Wed Sep 15 2021 Matej Cepl <mcepl@suse.com>
- Fix the patch metadata in the SPEC file.
* Wed Sep 15 2021 pgajdos@suse.com
- %%check: use %%pyunittest_arch rpm macro
- added patches
  fix https://github.com/fancycode/pylzma/issues/76
  + python-pylzma-test-python3.patch
* Wed Jan  2 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.5.0:
  * Update to LZMA SDK 18.05.
  * Support LZMA2 decompression.
  * Fix decompressing empty members from 7z files.
  * Fix parsing attributes from 7z members.
  * Include test data in tarball.
  * Fix AES decryption for solid 7z archives with LZMA2 compression.
* Thu Jul 26 2018 tchvatal@suse.com
- Move urls to github, pypi tarball does not contain tests, upstream
  fixed it for future releases
* Thu Jul 26 2018 tchvatal@suse.com
- Switch to singlespec
- Update to 0.4.9:
  * support python3
* Wed Aug 19 2015 nemysis@openSUSE.org
- Update to 0.4.8, no changelog entry
* Sun Jun  7 2015 nemysis@gmx.ch
- Update to 0.4.6, no changelog entry
- Use %%{oname} instead of pylzma
- Use %%{module} instead of py7zlib
- Change URL
- Add BuildRequires for fdupes and use %%fdupes macro to reduce size of the package
- Change Description
- Add sed, fix Shebang
- Use right files name instead of %%{python_sitearch}
* Wed Nov 27 2013 p.drouand@gmail.com
- Update to version 0.4.4
  + No changelog available
- Add Python prefix to spec file and .changes file
- Add a head to spec file
- Others improvements
* Mon Jun  9 2008 poeml@suse.de
- package created (scrounged from Mandriva) (0.3.0)
